@@ -6,8 +6,6 @@
 		     	pattern matching, evaluation and output
 	Version history: Original version February 1995 by JJ & PK
 	Copyright: University of Helsinki, Dept. of Computer Science
-		   Distributed under GNU General Public Lisence
-		   See file COPYING for details
 */
 
 #include <stdio.h>
@@ -27,6 +25,8 @@
 #include <unistd.h>
 #endif
 
+extern int index_main(SgrepData *,int argc, char **argv);
+
 /*
  * struct for list of expression strings ( or files ) to be executed 
  */
@@ -107,7 +107,9 @@ struct OptionData {
  */
 const struct OptionData option_data[]= {
 	{ 'a',NULL,"act as a filter" },
+#if 0
 	{ 'C',NULL,"display copyright notice" },
+#endif
 	{ 'c',NULL,"display only count of matching regions" },
 	{ 'D',NULL,"obsolete synonym for -v"},
 	{ 'd',NULL,"don't do concat on result list"},
@@ -345,6 +347,21 @@ int main(int argc, char *argv[])
     return 0;
 }
 
+#if 0
+/*
+ * Displays the copyright notice.
+ */
+void copyright_notice()
+{
+	int i;
+	
+	for (i=0;copyright_text[i]!=NULL;i++)
+	{
+		printf("\t%s\n",copyright_text[i]);
+	}
+}
+#endif
+
 #if HAVE_TIMES
 static struct tms t_last;
 void CALC_TIME(struct tms *TIME) {
@@ -523,7 +540,6 @@ void print_help()
 	}
 	printf("  -- %-12s no more options\n","");
 	printf("Options can also be specified with "ENV_OPTIONS" environment variable\n");
-	printf("\nCopyright (C) 1998 University of Helsinki. Use sgrep -C for details,\n\n");	
 	exit(0);
 }
 
@@ -606,7 +622,7 @@ SgrepString *read_expressions(SgrepData *sgrep,
 	return_string=new_string(sgrep,8192);
 
 	/* Check for USER_SGREPRC */
-	if (getenv("HOME")) {
+	if (read_sgreprc && getenv("HOME")) {
 	    SgrepString *sgreprc=new_string(sgrep,1024);
 	    string_cat(sgreprc,getenv("HOME"));
 	    string_cat(sgreprc,"/");
@@ -624,7 +640,7 @@ SgrepString *read_expressions(SgrepData *sgrep,
 	}
 	
 	/* Check for SYSTEM_SGREPRC */
-	if (!test_stream) {
+	if (read_sgreprc && !test_stream) {
 	    test_stream=fopen(SYSTEM_SGREPRC,"r");
 	    if (test_stream) {
 		if (read_expression_file(return_string,SYSTEM_SGREPRC)
@@ -770,10 +786,12 @@ int get_options(char *argv[])
 		case 'N':
 			sgrep->print_newline=0;
 			break;
+#if 0
 		case 'C':
 			copyright_notice();
 			exit(0);
 			break;
+#endif
 		case 'f': {
 		    char *arg;
 		    struct Expression *e;
