@@ -8,8 +8,6 @@
 	             Used through fuction parse_tree()
 	Version history: Original version February 1995 by JJ & PK
 	Copyright: University of Helsinki, Dept. of Computer Science
-		   Distributed under GNU General Public Lisence
-		   See file COPYING for details
 */
 
 #include <ctype.h> /* FIXME: get rid of ctype.h */
@@ -351,7 +349,7 @@ enum Token next_token(Parser *parser)
 		real_parse_error(parser,"Unprintable character in phrase");
 		return W_PARSE_ERROR;
 	    }
-	    if (ch=='\"') 
+	    if (ch=='\"' && (i==0 || str[i-1]!='\\')) 
 	    {
 		str[i]=0;
 		*phrase=expand_backslashes(sgrep,str);
