@@ -5,16 +5,15 @@
 	Description: SGML/XML/HTML scanner, word tokenizer, character decoder
 	Version history: Original version December 1998 by JJ & PK
 	Copyright: University of Helsinki, Dept. of Computer Science
-		   Distributed under GNU General Public Lisence
-		   See file COPYING for details
 */
 
 #define SGREP_LIBRARY
-#include "sgrep.h"
 
 #include <string.h>
 #include <ctype.h>
 
+#include "sgrep.h"
+
 /* These come from the XML-specs */
 #define SGML_NameChars ("-a-zA-Z0-9._:")
 #define SGML_NameStartChars ("a-zA-Z_:")
@@ -1001,7 +1000,7 @@ int sgml_scan(SGMLScanner *scanner,
     if (encoder->prev==-1) encoder->prev=start;
     
     scanner->file_num=file_num;
-    i=-1;
+    i=0;
     ch=-1;
     while(1) {
 	if (ch==-1) {
