@@ -6,8 +6,6 @@
 		     all modules.
 	Version history: Original version February 1995 by JJ & PK
 	Copyright: University of Helsinki, Dept. of Computer Science
-		   Distributed under GNU General Public Lisence
-		   See file COPYING for details
 */
 
 
@@ -53,7 +51,7 @@
 /*
  * The hash table size for indexer term entries
  */
-#define DEFAULT_HASH_TABLE_SIZE 60013
+#define DEFAULT_HASH_TABLE_SIZE 1000003
 
 /* 
  * The default output styles
@@ -481,6 +479,9 @@ typedef struct SgrepStruct {
 #define realloc(X,y) you_should_use_sgrep_realloc_instead_of_plain_realloc()
 #define free(X) you_should_use_sgrep_free_instead_of_plain_free()
 #define calloc(X,Y) you_should_use_sgrep_calloc_instead_of_plain_calloc()
+#ifdef strdup
+# undef strdup
+#endif
 #define strdup(X) you_should_use_sgrep_strdup_instead_of_plain_strdup()
 
 void *sgrep_debug_malloc(SgrepData *, size_t, const char *, int);
@@ -532,7 +533,7 @@ int flist_last_errno(const FileList *list);
  * Miscellaneous
  */
 char *get_arg(SgrepData *,char *(*argv[]),int *i,int *j);
-void copyright_notice();
+extern const char *copyright_text[];
 FileList *check_files(SgrepData *sgrep,int ,char *[],int,char *[]);
 TempFile *create_named_temp_file(SgrepData *sgrep);
 TempFile *create_temp_file(SgrepData *sgrep);
@@ -582,7 +583,6 @@ typedef struct IndexEntryListStruct IndexEntryList;
 struct IndexEntryStruct;
 typedef struct IndexEntryStruct IndexEntry;
 
-int index_main(SgrepData *,int argc, char **argv);
 IndexReader *new_index_reader(SgrepData *sgrep,const char *index_file);
 void delete_index_reader(IndexReader *reader);
 RegionList *index_lookup(IndexReader *reader, const char *phrase);
